.. StoSpa2 documentation master file, created by
   sphinx-quickstart on Thu Jan 16 12:52:55 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

StoSpa2 - stochastic simulations of spatially extended systems
==============================================================

A C++ software package for stochastic simulations of spatially extended systems. Code-base has been completely
refactored since the previous version of [StoSpa](https://github.com/BartoszBartmanski/StoSpa). Python
bindings have also been included.

.. toctree::
   :maxdepth: 2
   :caption: Contents

   install
   usage
   api


Index
=====

* :ref:`genindex`
